@@ -61,7 +61,7 @@ def get_relaxed_minimized_coexistent_unit_cell(eps: str, liquid=False) -> RealFi
 
 
 _coex_epsmu_bounds = {
-    '0.02': (0.080583046, 0.080583048)
+    '0.02': (0.080583046, 0.080583048),
     '0.04': (0.125627867, 0.125627868),
     '0.06': (0.152877453, 0.152877454),
     '0.08': (0.175436493, 0.175436494),
